@@ -5,8 +5,10 @@
 #include <QMetaType>
 #include <QDomDocument>
 
+#include "utils/qrefreshlist.h"
+
 class PhotoComment;
-typedef QList<PhotoComment> PhotoCommentList;
+typedef QRefreshList<PhotoComment> PhotoCommentList;
 
 #define NODE_PHOTO_COMMENT_ROOT "comment"
 #define NODE_PHOTO_COMMENT_ID "id"
