@@ -32,12 +32,12 @@ ImageBrowserPanel::ImageBrowserPanel(QWidget *parent) :
             SLOT(updateAccounts(QString,AccountList)));
 
     // check that one acount mast be setup
-//    if (this->sm->getAccounts().length() != 0) {
-//        this->refreshFriends(false);
-//        this->refreshAlbums(false);
+    if (this->sm->getAccounts().length() != 0) {
+        this->refreshFriends(false);
+        this->refreshAlbums(false);
 //        this->refreshPhotos(false);
-//        this->refreshFeed(false);
-//    }
+        this->refreshFeed(false);
+    }
 
     this->setState();
     this->peopleradb->toggle();
@@ -72,12 +72,12 @@ ImageBrowserPanel::ImageBrowserPanel(ServiceMgr *mgr, QWidget *parent) :
             SLOT(updateAccounts(QString, AccountList)));
 
     // check that one acount mast be setup
-//    if (this->sm->getAccounts().length() != 0) {
-//        this->refreshFriends(false);
-//        this->refreshAlbums(false);
+    if (this->sm->getAccounts().length() != 0) {
+        this->refreshFriends(false);
+        this->refreshAlbums(false);
 //        this->refreshPhotos(false);
-//        this->refreshFeed(false);
-//    }
+        this->refreshFeed(false);
+    }
 
     this->setState();
     this->peopleradb->toggle();
